"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.QUIZ_SUBMISSION_EVENT = exports.SESSION_STARTED_OR_RESUMED_EVENT = exports.EVENT_RESPONSE = exports.RESPONSE = void 0;

var _humps = require("humps");

function eventType() {
  var eventTransform = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : function (data) {
    return data;
  };
  return function (data) {
    var quizSessionId = data.quizSessionId,
        accountUuid = data.accountUuid;
    var createdAt = "".concat(new Date().toISOString(), "|").concat(window.performance.now());
    var quizSessionKey = "".concat(quizSessionId, "|").concat(accountUuid);
    var serializedData = JSON.stringify((0, _humps.decamelizeKeys)(Object.assign(eventTransform(data), {
      createdAt: createdAt
    }))); // AWS-SDK uses capitalized properties :\

    return {
      Data: serializedData,
      PartitionKey: quizSessionKey
    };
  };
}

var RESPONSE = eventType(function (data) {
  // The resume (response_events) stream doesn't care about eventData contents
  // Clean them up!
  // Required to prevent modification of the source data
  var adjustedData = Object.assign({}, data);
  adjustedData.eventData = Object.assign({}, data.eventData);
  'position userResponse itemId'.split(' ').forEach(function (prop) {
    adjustedData[prop] = adjustedData.eventData[prop];
    delete adjustedData.eventData[prop];
  });
  return adjustedData;
});
exports.RESPONSE = RESPONSE;
var EVENT_RESPONSE = eventType();
exports.EVENT_RESPONSE = EVENT_RESPONSE;
var SESSION_STARTED_OR_RESUMED_EVENT = eventType();
exports.SESSION_STARTED_OR_RESUMED_EVENT = SESSION_STARTED_OR_RESUMED_EVENT;
var QUIZ_SUBMISSION_EVENT = eventType();
exports.QUIZ_SUBMISSION_EVENT = QUIZ_SUBMISSION_EVENT;