"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.formatTime = formatTime;
exports.formatTimespan = void 0;

var _formatMessage = _interopRequireDefault(require("@instructure/quiz-i18n/lib/format-message"));

var _default_ru_number = Intl.NumberFormat("ru", { style: "decimal" }).format;
var minuteDuration = 60;
var hourDuration = 3600;

var formatHours = function formatHours(hours) {
  var _s, _n, _v, _i;

  return _s = hours, _n = +_s, (_v = (_s + '.').split('.')[1].length, _i = Math.floor(Math.abs(+_s)), _v === 0 && _i % 10 === 1 && _i % 100 !== 11 ? _default_ru_number(hours) + " \u0447\u0430\u0441" : _default_ru_number(hours) + " \u0447\u0430\u0441\u044B");
};

var formatMinutes = function formatMinutes(minutes) {
  var _s2, _n2, _v2, _i2;

  return _s2 = minutes, _n2 = +_s2, (_v2 = (_s2 + '.').split('.')[1].length, _i2 = Math.floor(Math.abs(+_s2)), _v2 === 0 && _i2 % 10 === 1 && _i2 % 100 !== 11 ? _default_ru_number(minutes) + " \u043C\u0438\u043D\u0443\u0442\u0430" : _default_ru_number(minutes) + " \u043C\u0438\u043D\u0443\u0442\u044B");
};

var formatSeconds = function formatSeconds(seconds) {
  var _s3, _n3, _v3, _i3;

  return _s3 = seconds, _n3 = +_s3, (_v3 = (_s3 + '.').split('.')[1].length, _i3 = Math.floor(Math.abs(+_s3)), _v3 === 0 && _i3 % 10 === 1 && _i3 % 100 !== 11 ? _default_ru_number(seconds) + " \u0441\u0435\u043A\u0443\u043D\u0434\u0430" : _default_ru_number(seconds) + " \u0441\u0435\u043A\u0443\u043D\u0434\u044B(-\u044B)");
};

var formatTimespan = function formatTimespan(startTime, endTime) {
  return formatTime(endTime - startTime, 1000);
};

exports.formatTimespan = formatTimespan;

function formatTime(time) {
  var secondDuration = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : 1;
  var totalSeconds = Math.floor(time / secondDuration);
  var parts = [];
  var hours = Math.floor(totalSeconds / hourDuration);

  if (hours !== 0) {
    parts.push(formatHours(hours));
  }

  var minutes = Math.floor(totalSeconds / minuteDuration) % minuteDuration;

  if (minutes !== 0) {
    parts.push(formatMinutes(minutes));
  }

  var seconds = totalSeconds % minuteDuration;

  if (seconds !== 0 || parts.length === 0) {
    parts.push(formatSeconds(seconds));
  }

  var separator = " ";
  return parts.join(separator);
}